'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var R = _interopRequireWildcard(_ramda);

var _xodFuncTools = require('xod-func-tools');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

// ProgressData :: { note: String, total: Number, current: Number, percentage: Number }

/**
 * Returns a function, which increments the current step on each call and
 * returns a new object with `ProgressData`.
 *
 * :: Number -> (String -> ProgressData)
 */
exports.default = total => {
  let current = 0;

  /**
   * Increments `current` and returns `ProgressData`.
   * :: String -> ProgressData
   */
  const next = note => {
    current += 1;
    return {
      total,
      current,
      note,
      percentage: (0, _xodFuncTools.roundTo)(2, current / total)
    };
  };

  /**
   * Utility
   * Increments `current` and returns `ProgressData`.
   * But accepts `ProgressData` as the argument.
   *
   * Handy when some function with progress uses another function with
   * progress and we need to get a truthy percentage over the whole process.
   *
   * :: ProgressData -> ProgressData
   */
  const wrap = R.pipe(R.prop('note'), next);

  const fn = note => next(note);
  fn.wrap = data => wrap(data);
  return fn;
};