'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _extractZip = require('extract-zip');

var _extractZip2 = _interopRequireDefault(_extractZip);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO: Add unpack functions for other archives

/**
 * Unpacks zip in the same directory.
 * Returns `Promise` with the name of the unpacked root directory.
 * E.G.
 * 1. We downloaded "my-lib.zip".
 *    And it has an "awe$ome-library" directory in the root.
 * 2. Called `unpackZip('/my/path/my-lib.zip')`.
 *    It unpacked archive into `/my/path/awe$ome-library/`.
 *    And returned Promise with `awe$some-library/`.
 * 3. Then we can do something with this directory on next steps.
 *    E.G. rename to the normalized name.
 *
 * :: Path -> Promise Path Error
 */
exports.default = filePath => new Promise((resolve, reject) => {
  let originalRootDirName = null;
  (0, _extractZip2.default)(filePath, {
    dir: _path2.default.dirname(filePath),
    onEntry: entry => {
      // It reads zip from the beggining, so first entry will be
      // the root directory (if archive contains root directory).
      // But our archives have root directory now.
      // We store it into a variable to rename it later.
      // TODO: Make it more solid
      if (originalRootDirName) return;
      originalRootDirName = _path2.default.basename(entry.fileName);
    }
  }, err => {
    if (err) return reject(err);
    return resolve(originalRootDirName);
  });
});